@@ -37,7 +37,7 @@ expect_equivalent(iris[, c("Petal.Length", "Petal.Width")], newdf) # skip attrib
 
 
 ## test list
-arr <- tiledb_array(uri)
+arr <- tiledb_array(uri, return_as="asis")
 res <- arr[]
 expect_equal(class(res), "list")
 expect_equal(length(res), 6)            # plus one for 'rows'
@@ -266,3 +266,18 @@ arr <- tiledb_array(uri, as.data.frame=TRUE)
 chk <- arr[]
 if (getRversion() <  '4.0.0') chk$char <- as.character(chk$char)
 expect_equivalent(df, chk)              # skip attribute
+
+## explicit dense data.frame
+df <- data.frame(aa=1:26,
+                 bb=26:1,
+                 cc=letters,
+                 dd=LETTERS)
+uri <- tempfile()
+fromDataFrame(df, uri, sparse=FALSE)
+arr <- tiledb_array(uri, return_as="data.frame", extended=FALSE)  # skip row index on return
+res <- arr[]
+if (getRversion() < '4.0.0') {
+    res$cc <- as.character(res$cc)
+    res$dd <- as.character(res$dd)
+}
+expect_equivalent(df, res)
